@@ -22,7 +22,7 @@ use Template::Provider::FromDATA;
 use Data::Merger qw/merger/;
 use base qw/Exporter/;
 
-our $VERSION     = version->new('0.0.1');
+our $VERSION     = version->new('0.0.2');
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 
@@ -337,13 +337,21 @@ sub list_templates {
 			no strict 'refs';            ## no critic
 			$fh = \*{"${module}\::DATA"};
 		}
+		my $lines = 0;
 
 		LINE:
 		while ( my $line = <$fh> ) {
+			$lines++;
 			my ($template) = $line =~ /^__(.+)__\r?\n/xms;
 			next LINE if !$template;
 			push @files, { path => $module, file => $template };
 		}
+
+		# if no lines read check the provider cache
+		if ( !$lines ) {
+			my $cache = $self->{providers}[1]->{cache}{templates};
+			push @files, map {{ file => $_ }} keys %{ $cache };
+		}
 	}
 
 	return @files;
@@ -371,7 +379,7 @@ App::TemplateCMD - Sets up an interface to passing Template Toolkit templates
 
 =head1 VERSION
 
-This documentation refers to App::TemplateCMD version 0.1.
+This documentation refers to App::TemplateCMD version 0.0.2.
 
 =head1 SYNOPSIS
 
