@@ -10,7 +10,6 @@ use strict;
 use warnings;
 use version;
 use Carp;
-use Scalar::Util;
 use List::MoreUtils qw/uniq/;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
@@ -19,7 +18,7 @@ use Template::Provider;
 use YAML qw/Load/;
 use base qw/App::TemplateCMD::Command/;
 
-our $VERSION     = version->new('0.0.1');
+our $VERSION     = version->new('0.0.2');
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 
@@ -88,7 +87,7 @@ App::TemplateCMD::Command::Build - Builds a a tree of files from a build templat
 
 =head1 VERSION
 
-This documentation refers to App::TemplateCMD::Command::Build version 0.1.
+This documentation refers to App::TemplateCMD::Command::Build version 0.0.2.
 
 =head1 SYNOPSIS
 
